@@ -23,6 +23,7 @@ def connect(dirname="data/postgresqlite", sqlite_compatible=True, config=None):
         pg8000.dbapi.Cursor._fetchone = pg8000.dbapi.Cursor.fetchone
         pg8000.dbapi.Cursor.fetchall = _cursor_fetchall
         pg8000.dbapi.Cursor.fetchone = _cursor_fetchone
+        pg8000.dbapi.Cursor.__iter__ = _cursor_iter
 
     config = config or get_config(dirname)
     connection = pg8000.dbapi.connect(user=config.user, password=config.password, unix_sock=config.socket)
@@ -72,6 +73,12 @@ def _cursor_fetchall(self):
         results.append(DictRow(result,lookup))
 
 
+def _cursor_iter(self):
+	lookup = _create_lookup_dict(self.description)
+	while (row := self._fetchone()) is not None:
+		yield DictRow(row, lookup)
+
+
 def get_uri(dirname="data/postgresqlite", driver="pg8000"):
     """Start a server (if needed), wait for it, and return a connection URL.    
     Args:
